==> TipTheScales-fabric-1.21.8-23.0.0.1-sources.jar: com/blamejared/tipthescales/mixin/MixinVideoSettingsScreen.java <==
package com.blamejared.tipthescales.mixin;

import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import java.util.Objects;
import net.minecraft.class_2561;
import net.minecraft.class_315;
import net.minecraft.class_437;
import net.minecraft.class_446;
import net.minecraft.class_4667;

@Mixin(class_446.class)
public abstract class MixinVideoSettingsScreen extends class_4667 {
    
    @Unique
    public int tipthescales$cachedGuiScale;
    
    public MixinVideoSettingsScreen(class_437 parent, class_315 options, class_2561 title) {
        
        super(parent, options, title);
    }
    
    @Inject(method = "mouseClicked", at = @At(value = "HEAD"))
    public void tipTheScales$mouseClickedHead(double mouseX, double mouseY, int button, CallbackInfoReturnable<Boolean> cir) {
        
        tipthescales$cachedGuiScale = this.field_21336.method_42474().method_41753();
    }
    
    // This feels horrible, but I am not sure how better to do it, and I don't *think* other mods will do this, I hope anyway, future me will deal with it
    @Override
    public boolean method_25406(double $$0, double $$1, int $$2) {
        
        if(this.field_21336.method_42474().method_41753() != tipthescales$cachedGuiScale) {
            Objects.requireNonNull(this.field_22787).method_15993();
        }
        tipthescales$cachedGuiScale = this.field_21336.method_42474().method_41753();
        return super.method_25406($$0, $$1, $$2);
    }
    
}

==> TipTheScales-fabric-1.21.11-25.0.0.1-sources.jar: com/blamejared/tipthescales/mixin/MixinVideoSettingsScreen.java <==
package com.blamejared.tipthescales.mixin;

import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import java.util.Objects;
import net.minecraft.class_11909;
import net.minecraft.class_2561;
import net.minecraft.class_315;
import net.minecraft.class_437;
import net.minecraft.class_446;
import net.minecraft.class_4667;

@Mixin(class_446.class)
public abstract class MixinVideoSettingsScreen extends class_4667 {
    
    @Unique
    public int tipthescales$cachedGuiScale;
    
    public MixinVideoSettingsScreen(class_437 parent, class_315 options, class_2561 title) {
        
        super(parent, options, title);
    }
    
    @Inject(method = "mouseClicked", at = @At(value = "HEAD"))
    public void tipTheScales$mouseClickedHead(class_11909 event, boolean doubleClick, CallbackInfoReturnable<Boolean> cir) {
        
        tipthescales$cachedGuiScale = this.field_21336.method_42474().method_41753();
    }
    
    // This feels horrible, but I am not sure how better to do it, and I don't *think* other mods will do this, I hope anyway, future me will deal with it
    @Override
    public boolean method_25406(class_11909 event) {
        
        if(this.field_21336.method_42474().method_41753() != tipthescales$cachedGuiScale) {
            Objects.requireNonNull(this.field_22787).method_15993();
        }
        tipthescales$cachedGuiScale = this.field_21336.method_42474().method_41753();
        return super.method_25406(event);
    }
    
}
